package com.lantone.qc.kernel.catalogue.beilun.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.entity.Menses;
import com.lantone.qc.pub.model.label.MenstrualLabel;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : BEH0063
 * @Description : 月经史未描述末次月经时间/闭经日期/绝经年龄
 * @Author : 胡敬
 * @Date: 2020-03-11 14:26
 */
@Component
public class BEH0063 extends QCCatalogue {
    @Override
    protected void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if (inputInfo.getBeHospitalizedDoc() != null) {
            if (inputInfo.getBeHospitalizedDoc().getStructureMap() == null
                    || inputInfo.getBeHospitalizedDoc().getStructureMap().get("性别") == null
                    || inputInfo.getBeHospitalizedDoc().getStructureMap().get("性别").contains("男")) {
                status.set("0"); //如果性别是男,就不报错
            } else {
                Map<String, String> structureMap = inputInfo.getBeHospitalizedDoc().getStructureMap();
                if (StringUtil.isNotBlank(structureMap.get("末次月经日期"))
                        || StringUtil.isNotBlank(structureMap.get("绝经年龄"))) {
                    status.set("0");
                    return;
                }
                if (inputInfo.getBeHospitalizedDoc().getMenstrualLabel() != null) {
                    MenstrualLabel menstrualLabel = inputInfo.getBeHospitalizedDoc().getMenstrualLabel();
                    String text = menstrualLabel.getText();
                    if (StringUtil.isNotBlank(text) && text.contains("未行经")) {
                        status.set("0");
                        return;
                    }
                    List<Menses> mensesList = menstrualLabel.getMensesList();
                    if (ListUtil.isEmpty(mensesList)) {
                        return;
                    }
                    boolean isFindLastMenstrual = false, isFindMenopauseTime = false, isFindMenopauseAge = false;
                    for (Menses menses : mensesList) {
                        if (menses.getLastMenstrual() != null && StringUtil.isNotBlank(menses.getLastMenstrual().getName())) { //末次月经时间
                            isFindLastMenstrual = true;
                        }
                        if (menses.getMenopauseTime() != null && StringUtil.isNotBlank(menses.getMenopauseTime().getName())) { //闭经日期
                            isFindMenopauseTime = true;
                        }
                        if (menses.getMenopauseAge() != null && StringUtil.isNotBlank(menses.getMenopauseAge().getName())) { //绝经年龄
                            isFindMenopauseAge = true;
                        }
                        if (isFindLastMenstrual && isFindMenopauseTime && isFindMenopauseAge) {
                            status.set("0");
                            return;
                        }
                    }
                }
            }
        }
    }
}