package com.lantone.qc.kernel.catalogue.beilun.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.entity.MaritalStatus;
import com.lantone.qc.pub.model.label.MaritalLabel;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

/**
 * @Description: 婚姻状况前后不一致
 * @author: rengb
 * @time: 2020/3/10 14:02
 */
@Component
public class BEH0372 extends QCCatalogue {

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if (inputInfo.getBeHospitalizedDoc() == null) {
            status.set("0");
            return;
        }

        String basicInfoStatus = inputInfo.getBeHospitalizedDoc().getStructureMap().get("婚育史");
        String bhbasicInfoStatus = inputInfo.getBeHospitalizedDoc().getStructureMap().get("婚姻状况");
        if (StringUtil.isBlank(bhbasicInfoStatus)) {
            bhbasicInfoStatus = inputInfo.getBeHospitalizedDoc().getStructureMap().get("婚姻");
        }
        if (StringUtil.isBlank(basicInfoStatus) || StringUtil.isBlank(bhbasicInfoStatus)) {
            status.set("0");
            return;
        }

        if (bhbasicInfoStatus.equals("未婚") && basicInfoStatus.contains("结婚")) {
            return;
        }

        if (bhbasicInfoStatus.equals("未婚") && basicInfoStatus.contains("未婚")) {
            status.set("0");
            return;
        }

        if (StringUtil.isNotBlank(bhbasicInfoStatus) && basicInfoStatus.equals("其他")) {
            status.set("0");
            return;
        }

        if (bhbasicInfoStatus.equals("丧偶") && basicInfoStatus.contains("已故")) {
            status.set("0");
            return;
        }

        if ((bhbasicInfoStatus.equals("离婚") || bhbasicInfoStatus.equals("离异")) &&
                (basicInfoStatus.contains("离异") || bhbasicInfoStatus.equals("离婚"))) {
            status.set("0");
            return;
        }

        if (bhbasicInfoStatus.equals("已婚") && basicInfoStatus.contains("结婚")) {
            status.set("0");
            return;
        }

        MaritalStatus mts = inputInfo.getBeHospitalizedDoc().getMaritalLabel().getMaritalStatus();
        if (mts != null && StringUtil.isNotBlank(mts.getName())) {
            String maritalStatus = mts.getName();
            if (basicInfoStatus.equals(maritalStatus)) {
                status.set("0");
                return;
            }
        }

        //无婚育史
        MaritalLabel maritalLabel = inputInfo.getBeHospitalizedDoc().getMaritalLabel();
        if (maritalLabel == null || maritalLabel.getText() == null) {
            status.set("0");
        }
    }

}