package com.lantone.qc.kernel.catalogue.beilun.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import org.springframework.stereotype.Component;

import java.util.Map;


/**
 * @ClassName : BEH0417
 * @Description : 入院记录出生地填写错误
 * @Author : 楼辉荣
 * @Date: 2020-03-06 17:28
 */
@Component
public class BEH0417 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        if (inputInfo.getBeHospitalizedDoc() == null || inputInfo.getFirstPageRecordDoc() == null) {
            return;
        }
        Map<String, String> structureMap = inputInfo.getBeHospitalizedDoc().getStructureMap();
        Map<String, String> firstStructMap = inputInfo.getFirstPageRecordDoc().getStructureMap();
        if (structureMap != null && firstStructMap != null) {
            String contactAddress_bh = structureMap.get("出生地");
            String contactAddress_first = firstStructMap.get(Content.birth_address);
            if (!CatalogueUtil.isEmpty(contactAddress_bh) && !CatalogueUtil.isEmpty(contactAddress_first)) {
                if (contactAddress_bh.length() >=3 && contactAddress_first.length() >= 3) {
                    if (contactAddress_first.contains(getArea(contactAddress_bh))) {
                        return ;
                    }
                    if (contactAddress_bh.contains(getArea(contactAddress_first))) {
                        return ;
                    }
                }
                // 地址主要包含即可
                if (!contactAddress_first.contains(contactAddress_bh) && !contactAddress_bh.contains(contactAddress_first)) {
                    status.set("-1");
                }
            }
        }
    }

    /**
     * 获取县前2个字，没有县就取最后2个字
     * @param addr
     * @return
     */
    public String getArea(String addr) {
        if (addr.contains("县") && addr.lastIndexOf("县") >= 2) {
            return addr.substring(addr.lastIndexOf("县") - 2, addr.lastIndexOf("县"));
        } else if (addr.length() > 2) {
            return addr.substring(addr.length()-2);
        }
        return "";
    }
}