package com.lantone.qc.kernel.catalogue.beilun.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.ward.AttendingDoctorWardDoc;
import com.lantone.qc.pub.model.label.ThreeLevelWardLabel;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR0133
 * @Description : 上级医师（主治医师）首次查房无诊疗计划
 * @Author : 胡敬
 * @Date: 2020-03-23 14:16
 */
@Component
public class THR0133 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if (inputInfo.getThreeLevelWardDocs().size() == 0 || inputInfo.getBeHospitalizedDoc() == null) {
            status.set("0");
            return;
        }
        List<AttendingDoctorWardDoc> attendDocs = inputInfo.getThreeLevelWardDocs().get(0).getAttendingDoctorWardDocs();
        if (attendDocs.size() == 0) {
            status.set("0");
            return;
        }
        AttendingDoctorWardDoc firstAttendDoc = attendDocs.get(0);
        //先取结构化数据判断
        Map<String, String> firstAttendStructureMap = firstAttendDoc.getStructureMap();
        String admisDateStr = inputInfo.getBeHospitalizedDoc().getStructureMap().get("入院日期");
        String recordDateStr = firstAttendStructureMap.get("查房日期");
        if (CatalogueUtil.isEmpty(admisDateStr) || CatalogueUtil.isEmpty(recordDateStr)) {
            status.set("0");
            return;
        }
        //如果首次查房超过48小时则不判断该条规则
        if (CatalogueUtil.compareTime(StringUtil.parseDateTime(admisDateStr), StringUtil.parseDateTime(recordDateStr), 48 * 60L)) {
            status.set("0");
            return;
        }
        if (StringUtil.isNotBlank(firstAttendStructureMap.get("治疗计划和措施"))) {
            status.set("0");
            return;
        }
        ThreeLevelWardLabel firstAttendLabel = firstAttendDoc.getThreeLevelWardLabel();
        if (firstAttendLabel == null) {
            return;
        }

        if (firstAttendLabel.getTreatmentPlans().size() != 0) {
            status.set("0");
        }
    }
}