package com.lantone.qc.kernel.catalogue.beilun.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.ward.AttendingDoctorWardDoc;
import com.lantone.qc.pub.model.label.ThreeLevelWardLabel;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @ClassName : THR0134
 * @Description : 上级医师（主治医师）首次查房无初步诊断
 * @Author : 胡敬
 * @Date: 2020-03-23 14:16
 */
@Component
public class THR0134 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if (inputInfo.getThreeLevelWardDocs().size() == 0 || inputInfo.getBeHospitalizedDoc() == null) {
            status.set("0");
            return;
        }
        List<AttendingDoctorWardDoc> attendDocs = inputInfo.getThreeLevelWardDocs().get(0).getAttendingDoctorWardDocs();
        if (attendDocs.size() == 0) {
            status.set("0");
            return;
        }
        AttendingDoctorWardDoc firstAttendDoc = attendDocs.get(0);
        //先取结构化数据判断
        Map<String, String> firstAttendStructureMap = firstAttendDoc.getStructureMap();
        String admisDateStr = inputInfo.getBeHospitalizedDoc().getStructureMap().get("入院日期");
        String recordDateStr = firstAttendStructureMap.get("查房日期");
        String content = firstAttendStructureMap.get("病情记录");
        if (content.contains("诊断明确") || content.contains("目前诊断") || content.contains("目前考虑") || content.contains("当前诊断") ||
                content.contains("考虑诊断") || content.contains("诊断考虑") || content.contains("诊断基本明确") || content.contains("初步诊断") ||
                regexFind(content, "诊断", "基本明确")) {
            status.set("0");
            return;
        }
        if (CatalogueUtil.isEmpty(admisDateStr) || CatalogueUtil.isEmpty(recordDateStr)) {
            status.set("0");
            return;
        }
        //如果首次查房超过48小时则不判断该条规则
        if (CatalogueUtil.compareTime(StringUtil.parseDateTime(admisDateStr), StringUtil.parseDateTime(recordDateStr), 48 * 60L)) {
            status.set("0");
            return;
        }
        ThreeLevelWardLabel firstAttendLabel = firstAttendDoc.getThreeLevelWardLabel();
        if (firstAttendLabel == null) {
            return;
        }

        if (firstAttendLabel.getDiags().size() != 0 || StringUtil.isNotBlank(firstAttendLabel.getDiagText())) {
            status.set("0");
        }
    }

    private boolean regexFind(String content, String... str) {
        String s = "";
        for (String word : str) {
            s += word + ".*";
        }
        s = s.substring(0, s.lastIndexOf(".*"));
        Pattern p = Pattern.compile(s);
        Matcher m = p.matcher(content);
        return m.find();
    }
}