package com.lantone.qc.kernel.catalogue.beilun.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.FirstCourseRecordDoc;
import com.lantone.qc.pub.model.doc.ward.DirectorDoctorWardDoc;
import com.lantone.qc.pub.model.label.ThreeLevelWardLabel;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR0136
 * @Description : 上级医师（副主任医师/主任医师）首次查房无鉴别诊断
 * @Author : 胡敬
 * @Date: 2020-03-23 14:16
 */
@Component
public class THR0136 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if (inputInfo.getThreeLevelWardDocs().size() == 0 || inputInfo.getBeHospitalizedDoc() == null) {
            status.set("0");
            return;
        }
        FirstCourseRecordDoc firstCourseRecordDoc = inputInfo.getFirstCourseRecordDoc();
        if (firstCourseRecordDoc != null) {
            Map<String, String> structureMap = firstCourseRecordDoc.getStructureMap();
            String diffDiag = structureMap.get("鉴别诊断");
            if (StringUtil.isNotBlank(diffDiag) && (diffDiag.contains("诊断明确") || diffDiag.contains("无需鉴别") ||
                    diffDiag.contains("诊断基本明确"))) {
                status.set("0");
                return;
            }
        }
        List<DirectorDoctorWardDoc> directorDocs = inputInfo.getThreeLevelWardDocs().get(0).getDirectorDoctorWardDocs();
        if (directorDocs.size() == 0) {
            status.set("0");
            return;
        }
        DirectorDoctorWardDoc firstDirectDoc = directorDocs.get(0);
        //先取结构化数据判断
        Map<String, String> firstDirectStructureMap = firstDirectDoc.getStructureMap();
        String admisDateStr = inputInfo.getBeHospitalizedDoc().getStructureMap().get("入院日期");
        String recordDateStr = firstDirectStructureMap.get("查房日期");
        if (CatalogueUtil.isEmpty(admisDateStr) || CatalogueUtil.isEmpty(recordDateStr)) {
            status.set("0");
            return;
        }
        //如果首次查房超过72小时则不判断该条规则
        if (CatalogueUtil.compareTime(StringUtil.parseDateTime(admisDateStr), StringUtil.parseDateTime(recordDateStr), 72 * 60L)) {
            status.set("0");
            return;
        }
        String conditionRecord = firstDirectStructureMap.get("病情记录");
        if (StringUtil.isNotBlank(conditionRecord)) {
            if (conditionRecord.contains("鉴别")
                    || conditionRecord.contains("诊断明确")
                    || conditionRecord.contains("无需鉴别")
                    || conditionRecord.contains("诊断基本明确")) {
                status.set("0");
                return;
            }
        }
        ThreeLevelWardLabel firstDirectLabel = firstDirectDoc.getThreeLevelWardLabel();
        if (firstDirectLabel == null) {
            return;
        }

        if (firstDirectLabel.getDiffDiag().size() != 0 || StringUtil.isNotBlank(firstDirectLabel.getDiffDiagText())) {
            status.set("0");
        }
    }
}