package com.lantone.qc.kernel.catalogue.yiwu.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.entity.Allergy;
import com.lantone.qc.pub.model.label.PastLabel;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @Description: 食物过敏史未填写
 * @author: rengb
 * @time: 2020/3/10 14:02
 */
@Component
public class BEH0026 extends QCCatalogue {

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if (inputInfo.getBeHospitalizedDoc() == null) {
            status.set("0");
            return;
        }
        Map<String, String> structureMap = inputInfo.getBeHospitalizedDoc().getStructureMap();
        if (StringUtils.isNotEmpty(structureMap.get("过敏史"))) {
            status.set("0");
            return;
        }
        PastLabel pastLabel = inputInfo.getBeHospitalizedDoc().getPastLabel();
        /* 如果既往史为空或者既往史文本为空，则不报错 */
        if (pastLabel == null || StringUtil.isBlank(pastLabel.getText())) {
            status.set("0");
            return;
        }
        String pastText = pastLabel.getText();
        if (pastText.contains("食物过敏史") || pastText.contains("详见原病历")) {
            status.set("0");
            return;
        }
        List<Allergy> allergies = pastLabel.getAllergies();
        if (ListUtil.isNotEmpty(allergies)) {
            long count = allergies.stream().filter(
                    i -> i != null
                            && StringUtil.isNotBlank(i.getName())
                    //                            && i.getAllergyFood() != null
                    //                            && StringUtil.isNotBlank(i.getAllergyFood().getName())
            ).count();
            if (count > 0) {
                status.set("0");
            }
        }
    }

}