package com.lantone.qc.kernel.catalogue.yiwu.behospitalized;

import com.google.common.collect.Lists;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.util.ListUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @Description: 慢病史未填写
 * @author: rengb
 * @time: 2020/3/10 14:02
 */
@Component
public class BEH0031 extends QCCatalogue {

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if (inputInfo.getBeHospitalizedDoc() == null) {
            status.set("0");
            return;
        }
        Map<String, String> structureMap = inputInfo.getBeHospitalizedDoc().getStructureMap();
        if (StringUtils.isNotEmpty(structureMap.get("高血压"))) {
            status.set("0");
            return;
        }

        if (ListUtil.isNotEmpty(
                CatalogueUtil.filterDiagsByNature(
                        inputInfo.getBeHospitalizedDoc().getPastLabel().getDiags(),
                        "chronic",
                        "1"
                )
        )) {
            status.set("0");
        }
        //硬规则匹配
        String text = inputInfo.getBeHospitalizedDoc().getPastLabel().getText();
        if (StringUtils.isNotEmpty(text)) {
            List<String> words = Lists.newArrayList("高血压", "糖尿病", "阿尔茨海默病", "帕金森", "冠心病心律失常型"
                    , "冠状动脉性心脏病", "冠状动脉粥样硬化性心脏病", "慢性肾炎综合征", "肾病", "慢性肾衰竭", "肾功能异常", "哮喘"
                    , "肺结核", "腹膜透析", "慢性阻塞性肺病", "精神分裂症", "分裂情感性精神病", "双相情感障碍，目前为缓解状态", "前列腺增生"
                    , "高脂血症", "高低密度脂蛋白胆固醇血症", "高胆固醇血症", "高甘油三酯血症", "骨质疏松", "慢性乙型病毒性肝炎"
                    , "慢性庚型肝炎", "慢性肝炎", "慢性丁型肝炎", "慢性病毒性肝炎", "慢性丙型病毒性肝炎", "酒精性肝病", "脂肪肝"
                    , "肝硬化", "肝恶性肿瘤", "肝恶性细胞瘤", "肝病", "类风湿性关节炎", "心脑血管", "内分泌");
            for (String word : words) {
                if (text.contains(word)) {
                    status.set("0");
                    return;
                }
            }
        }
    }

}