package com.lantone.qc.kernel.catalogue.yiwu.clinicalblood;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.ClinicalBloodDoc;
import com.lantone.qc.pub.util.ListUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : CLI0308
 * @Description :  输血记录中未记录是否有不良反应
 * @Author : 楼辉荣
 * @Date: 2020-03-06 17:28
 */
@Component
public class CLI0308 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        List<ClinicalBloodDoc> clinicalBloodDocs = inputInfo.getClinicalBloodDocs();
        if (ListUtil.isEmpty(clinicalBloodDocs)) {
            status.set("0");
            return;
        }

        if (clinicalBloodDocs != null && clinicalBloodDocs.size() > 0) {
            String regex = ".*(未.*|无.*|否.*).*(输血反应|不良反应).*";
            for (ClinicalBloodDoc cliB : clinicalBloodDocs) {
                Map<String, String> cliBStructureMap = cliB.getStructureMap();
                if (StringUtils.isNotEmpty(cliBStructureMap.get("输注后效果评价")) && (cliBStructureMap.get("输注后效果评价").contains("不良反应")
                        || cliBStructureMap.get("输注后效果评价").contains("不适") || cliBStructureMap.get("输注后效果评价").contains("未见"))) {
                    status.set("0");
                    break;
                }

                String infusion_process = cliBStructureMap.get("输注过程");
                if (StringUtils.isNotEmpty(infusion_process)) {
                    if (infusion_process.matches(regex) || infusion_process.contains("无") || infusion_process.contains("未见")
                    || infusion_process.contains("未觉")) {
                        status.set("0");
                    } else {
                        status.set("-1");
                    }
                }

            }
        } else {
            status.set("0");
        }

    }
}