package com.lantone.qc.trans.beilun;

import com.google.common.collect.Lists;
import com.lantone.qc.pub.model.doc.DeathRecordDoc;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.FastJsonUtils;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.beilun.util.BeiLunDeathRecordHtmlAnalysis;
import com.lantone.qc.trans.beilun.util.BeiLunHtmlAnalysis;
import com.lantone.qc.trans.comsis.CommonAnalysisUtil;
import com.lantone.qc.trans.comsis.ModelDocGenerate;
import com.lantone.qc.trans.comsis.OrdinaryAssistant;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.MapUtils;

import java.util.List;
import java.util.Map;

/**
 * @Description: 死亡记录文档生成
 * @author: rengb
 * @time: 2020/3/17 13:23
 */
@Slf4j
public class BeiLunDeathRecordDocTrans extends ModelDocTrans {

    @Override
    public DeathRecordDoc extract(MedrecVo medrecVo) {
        DeathRecordDoc deathRecordDoc = null;
        try {
            Map<String, Object> contentMap = ((List<Map>) medrecVo.getContent().get("content")).get(0);
            String content = contentMap.get("xmlText").toString();
            Map<String, String> structureMap = null;
            if (contentMap.get("isParsed") != null && "1".equals(contentMap.get("isParsed").toString())) {
                structureMap = (Map) FastJsonUtils.getJsonToMap(content);
            } else {
                String recTitle = contentMap.get("recTitle").toString();
                String recTypeId = contentMap.get("recTypeId").toString();
                BeiLunHtmlAnalysis beiLunHtmlAnalysis = new BeiLunDeathRecordHtmlAnalysis();
                Map<String, String> sourceMap = beiLunHtmlAnalysis.analysis(content, recTitle, recTypeId);
                if (MapUtils.isNotEmpty(sourceMap)) {
                    structureMap = OrdinaryAssistant.mapKeyContrast(sourceMap, keyContrasts);
                    structureMap.put("记录编号", contentMap.get("recId").toString());
                    structureMap.put("病历号", contentMap.get("behospitalCode") == null ? null : contentMap.get("behospitalCode").toString());
                }
            }
            if (MapUtils.isNotEmpty(structureMap)) {
                deathRecordDoc = ModelDocGenerate.deathRecordDocGen(structureMap);
                deathRecordDoc.setText(CommonAnalysisUtil.html2String(content));
                deathRecordDoc.setPageData((Map) structureMap);
            }
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return deathRecordDoc;
    }

    private List<String> keyContrasts = Lists.newArrayList(
            "签名时间=记录时间"
    );

}