package com.lantone.qc.trans.yiwu;

import com.google.common.collect.Lists;
import com.lantone.qc.dbanaly.facade.yiwu.YiWuXmlUtil;
import com.lantone.qc.dbanaly.util.ModuleMappingUtil;
import com.lantone.qc.pub.model.doc.PathologyShipDoc;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.FastJsonUtils;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.comsis.OrdinaryAssistant;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : PathologyShipDocTrans
 * @Description : 病理检验送检单
 * @Author : 楼辉荣
 * @Date: 2020-04-19 17:49
 */
public class YiWuPathologyShipDocTrans extends ModelDocTrans {
    private String modeId = "35";

    @Override
    public List<PathologyShipDoc> extract(MedrecVo medrecVo) {
        List<PathologyShipDoc> retList = Lists.newArrayList();
        List<Map<String, Object>> contentMaps = (List) medrecVo.getContent().get("content");
        contentMaps.forEach(contentMap -> {
            retList.add(getPathologyShipDoc(contentMap));
        });
        return retList;
    }

    private PathologyShipDoc getPathologyShipDoc(Map<String, Object> contentMap) {
        String content = contentMap.get("xmlText").toString();
        Map<String, String> structureMap = null;
        if (contentMap.get("isParsed") != null && "1".equals(contentMap.get("isParsed").toString())) {
            structureMap = (Map) FastJsonUtils.getJsonToMap(content);
        } else {
            Map<String, String> sourceMap = YiWuXmlUtil.xmlToMap(content);
            sourceMap.put("mode_id", ModuleMappingUtil.getDeptModuleId(modeId));
            sourceMap.put("mode_id=" + contentMap.get("modeId").toString(), "");
            sourceMap.put("rec_title=" + contentMap.get("recTitle").toString(), "");
            structureMap = OrdinaryAssistant.mapKeyContrast(sourceMap, keyContrasts, modeId);
        }
        PathologyShipDoc pathologyShipDoc = new PathologyShipDoc();
        pathologyShipDoc.setStructureMap(structureMap);
        pathologyShipDoc.setPageData((Map) structureMap);
        return pathologyShipDoc;
    }

    private List<String> keyContrasts = Lists.newArrayList("检验标本=送检标本名称",
            "本人姓名=姓名",
            "术中发现=手术所见");

}